@@ -84,8 +84,10 @@ def version():
         - 代码整理              # 2.7.6
         - 增加`flat_dc_ls`功能, 可以将返回的dc_ls展平为list
         - 取消`distinct_field_ls`和`order_type_ls`的捆绑      # 2.7.7
+        - BaseListView的排序字段跟模型的排序字段联动起来      # 2.7.8
+        - 整理`ListStatisticMixin`, 增加统计字段功能
     """
-    v = "2.7.7"     # 查看当前已发布版本: https://pypi.org/search/?q=bddjango
+    v = "2.7.8"     # 查看当前已发布版本: https://pypi.org/search/?q=bddjango
     return v
 
 
